@@ -142,7 +142,7 @@ def create_department(data: dict) -> dict:
     else:
         if Department.objects.filter(organization_id=data["organization_id"]).exists():
             raise ValueError(f"organization: {data['organization_id']} already has a level-1 department")
-        path = []
+        path = None
 
     # 找到最大排序数
     show_order = Department.objects.aggregate(num=Max('show_order'))["num"]
